Index: code/branches/cpp11_v3/src/modules/notifications/NotificationDispatcher.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/notifications/NotificationDispatcher.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/notifications/NotificationDispatcher.cc	(revision 11054)
@@ -177,8 +177,8 @@
 
         PlayerTrigger* pTrigger = orxonox_cast<PlayerTrigger*>(trigger);
-        PlayerInfo* player = NULL;
+        PlayerInfo* player = nullptr;
 
         // If the trigger is a PlayerTrigger.
-        if(pTrigger != NULL)
+        if(pTrigger != nullptr)
         {
             if(!pTrigger->isForPlayer())  // The PlayerTrigger is not exclusively for Pawns which means we cannot extract one.
@@ -190,5 +190,5 @@
             return false;
 
-        if(player == NULL)
+        if(player == nullptr)
         {
             orxout(verbose, context::notifications) << "The NotificationDispatcher was triggered by an entity other than a Pawn. (" << trigger->getIdentifier()->getName() << ")" << endl;
Index: code/branches/cpp11_v3/src/modules/notifications/NotificationDispatcher.h
===================================================================
--- code/branches/cpp11_v3/src/modules/notifications/NotificationDispatcher.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/notifications/NotificationDispatcher.h	(revision 11054)
@@ -79,6 +79,6 @@
             virtual ~NotificationDispatcher(); //!< Destructor.
 
-            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode); //!< Method for creating a NotificationDispatcher object through XML.
-            virtual void XMLEventPort(Element& xmlelement, XMLPort::Mode mode);
+            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode) override; //!< Method for creating a NotificationDispatcher object through XML.
+            virtual void XMLEventPort(Element& xmlelement, XMLPort::Mode mode) override;
 
             /**
Index: code/branches/cpp11_v3/src/modules/notifications/NotificationManager.h
===================================================================
--- code/branches/cpp11_v3/src/modules/notifications/NotificationManager.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/notifications/NotificationManager.h	(revision 11054)
@@ -120,5 +120,5 @@
             virtual ~NotificationManager();
 
-            virtual void preDestroy(void); // Is called before the object is destroyed.
+            virtual void preDestroy(void) override; // Is called before the object is destroyed.
 
             /**
@@ -128,6 +128,6 @@
             static NotificationManager& getInstance() { return Singleton<NotificationManager>::getInstance(); } // tolua_export
 
-            virtual bool registerNotification(const std::string& message, const std::string& sender, notificationMessageType::Value type);
-            virtual bool executeCommand(notificationCommand::Value command, const std::string& sender);
+            virtual bool registerNotification(const std::string& message, const std::string& sender, notificationMessageType::Value type) override;
+            virtual bool executeCommand(notificationCommand::Value command, const std::string& sender) override;
 
             bool registerNotification(Notification* notification); // Registers a Notification within the NotificationManager.
Index: code/branches/cpp11_v3/src/modules/notifications/NotificationQueue.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/notifications/NotificationQueue.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/notifications/NotificationQueue.cc	(revision 11054)
@@ -206,8 +206,8 @@
         {
             // Add all Notifications that have been created after this NotificationQueue was created.
-            for(std::multimap<std::time_t, Notification*>::iterator it = notifications->begin(); it != notifications->end(); it++)
+            for(const auto& mapEntry : *notifications)
             {
-                if(it->first >= this->creationTime_)
-                    this->push(it->second, it->first);
+                if(mapEntry.first >= this->creationTime_)
+                    this->push(mapEntry.second, mapEntry.first);
             }
         }
@@ -336,6 +336,6 @@
         this->ordering_.clear();
         // Delete all NotificationContainers in the list.
-        for(std::vector<NotificationContainer*>::iterator it = this->notifications_.begin(); it != this->notifications_.end(); it++)
-            delete *it;
+        for(NotificationContainer* notification : this->notifications_)
+            delete notification;
 
         this->notifications_.clear();
@@ -426,5 +426,5 @@
         bool first = true;
         // Iterate through the set of targets.
-        for(std::set<std::string>::const_iterator it = this->targets_.begin(); it != this->targets_.end(); it++)
+        for(const std::string& target : this->targets_)
         {
             if(!first)
@@ -432,5 +432,5 @@
             else
                 first = false;
-            stream << *it;
+            stream << target;
         }
 
Index: code/branches/cpp11_v3/src/modules/notifications/NotificationQueue.h
===================================================================
--- code/branches/cpp11_v3/src/modules/notifications/NotificationQueue.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/notifications/NotificationQueue.h	(revision 11054)
@@ -97,8 +97,8 @@
             virtual ~NotificationQueue();
 
-            virtual void tick(float dt); // To update from time to time.
-            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode);
-
-            virtual void changedName(void);
+            virtual void tick(float dt) override; // To update from time to time.
+            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode) override;
+
+            virtual void changedName(void) override;
             
             void update(void); // Updates the NotificationQueue.
Index: code/branches/cpp11_v3/src/modules/notifications/NotificationQueueCEGUI.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/notifications/NotificationQueueCEGUI.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/notifications/NotificationQueueCEGUI.cc	(revision 11054)
@@ -290,11 +290,11 @@
         The name of the NotificationQueueCEGUI to be got.
     @return
-        Returns a pointer to the NotificationQueueCEGUI, or NULL if it doesn't exist.
+        Returns a pointer to the NotificationQueueCEGUI, or nullptr if it doesn't exist.
     */
     /*static*/ NotificationQueueCEGUI* NotificationQueueCEGUI::getQueue(const std::string& name)
     {
         NotificationQueue* queue = NotificationManager::getInstance().getQueue(name);
-        if(queue == NULL || !queue->isA(Class(NotificationQueueCEGUI)))
-            return NULL;
+        if(queue == nullptr || !queue->isA(Class(NotificationQueueCEGUI)))
+            return nullptr;
         return static_cast<NotificationQueueCEGUI*>(queue);
     }
Index: code/branches/cpp11_v3/src/modules/notifications/NotificationQueueCEGUI.h
===================================================================
--- code/branches/cpp11_v3/src/modules/notifications/NotificationQueueCEGUI.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/notifications/NotificationQueueCEGUI.h	(revision 11054)
@@ -73,7 +73,7 @@
             virtual ~NotificationQueueCEGUI();
 
-            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode);
+            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode) override;
 
-            virtual void changedName(void);
+            virtual void changedName(void) override;
 
             void destroy(bool noGraphics = false); // Destroys the NotificationQueue.
@@ -136,11 +136,11 @@
             void registerVariables();
             
-            virtual void create(void); // Creates the NotificationQueue in lua.
+            virtual void create(void) override; // Creates the NotificationQueue in lua.
             
-            virtual void notificationPushed(Notification* notification); // Is called by the NotificationQueue when a Notification was pushed
-            virtual void notificationPopped(void); // Is called by the NotificationQueue when a Notification was popped.
-            virtual void notificationRemoved(unsigned int index); // Is called when a Notification was removed.
+            virtual void notificationPushed(Notification* notification) override; // Is called by the NotificationQueue when a Notification was pushed
+            virtual void notificationPopped(void) override; // Is called by the NotificationQueue when a Notification was popped.
+            virtual void notificationRemoved(unsigned int index) override; // Is called when a Notification was removed.
             
-            virtual void clear(bool noGraphics = false); // Clears the NotificationQueue by removing all NotificationContainers.
+            virtual void clear(bool noGraphics = false) override; // Clears the NotificationQueue by removing all NotificationContainers.
 
         protected:

Index: code/branches/cpp11_v3/src/modules/notifications/NotificationManager.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/notifications/NotificationManager.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/notifications/NotificationManager.cc	(revision 11054)
@@ -69,6 +69,6 @@
     {
         // Destroys all Notifications.
-        for(std::multimap<std::time_t, Notification*>::iterator it = this->allNotificationsList_.begin(); it!= this->allNotificationsList_.end(); it++)
-            it->second->destroy();
+        for(const auto& mapEntry : this->allNotificationsList_)
+            mapEntry.second->destroy();
         this->allNotificationsList_.clear();
 
@@ -152,10 +152,10 @@
         bool executed = false;
         // Clear all NotificationQueues that have the input sender as target.
-        for(std::map<const std::string, NotificationQueue*>::iterator it = this->queues_.begin(); it != this->queues_.end(); it++) // Iterate through all NotificationQueues.
-        {
-            const std::set<std::string>& set = it->second->getTargetsSet();
+        for(const auto& mapEntry : this->queues_) // Iterate through all NotificationQueues.
+        {
+            const std::set<std::string>& set = mapEntry.second->getTargetsSet();
             // If either the sender is 'all', the NotificationQueue has as target all or the NotificationQueue has the input sender as a target.
             if(all || set.find(NotificationListener::ALL) != set.end() || set.find(sender) != set.end())
-                executed = it->second->tidy() || executed;
+                executed = mapEntry.second->tidy() || executed;
         }
 
@@ -187,7 +187,7 @@
 
         // Insert the Notification in all NotificationQueues that have its sender as target.
-        for(std::map<const std::string, NotificationQueue*>::iterator it = this->queues_.begin(); it != this->queues_.end(); it++) // Iterate through all NotificationQueues.
-        {
-            const std::set<std::string>& set = it->second->getTargetsSet();
+        for(const auto& mapEntry : this->queues_) // Iterate through all NotificationQueues.
+        {
+            const std::set<std::string>& set = mapEntry.second->getTargetsSet();
             bool bAll = set.find(NotificationListener::ALL) != set.end();
             // If either the Notification has as sender 'all', the NotificationQueue displays all Notifications or the NotificationQueue has the sender of the Notification as target.
@@ -195,6 +195,6 @@
             {
                 if(!bAll)
-                    this->notificationLists_[it->second->getName()]->insert(std::pair<std::time_t, Notification*>(time, notification)); // Insert the Notification in the notifications list of the current NotificationQueue.
-                it->second->update(notification, time); // Update the NotificationQueue.
+                    this->notificationLists_[mapEntry.second->getName()]->insert(std::pair<std::time_t, Notification*>(time, notification)); // Insert the Notification in the notifications list of the current NotificationQueue.
+                mapEntry.second->update(notification, time); // Update the NotificationQueue.
             }
         }
@@ -334,5 +334,5 @@
         // If all senders are the target of the NotificationQueue, then the list of Notifications for that specific NotificationQueue is the same as the list of all Notifications.
         bool bAll = set.find(NotificationListener::ALL) != set.end();
-        std::multimap<std::time_t, Notification*>* map = NULL;
+        std::multimap<std::time_t, Notification*>* map = nullptr;
         if(bAll)
             this->notificationLists_[queue->getName()] = &this->allNotificationsList_;
@@ -345,8 +345,8 @@
 
         // Iterate through all Notifications to determine whether any of them should belong to the newly registered NotificationQueue.
-        for(std::multimap<std::time_t, Notification*>::iterator it = this->allNotificationsList_.begin(); it != this->allNotificationsList_.end(); it++)
-        {
-            if(!bAll && set.find(it->second->getSender()) != set.end()) // Checks whether the listener has the sender of the current Notification as target.
-                map->insert(std::pair<std::time_t, Notification*>(it->first, it->second));
+        for(const auto& mapEntry : this->allNotificationsList_)
+        {
+            if(!bAll && set.find(mapEntry.second->getSender()) != set.end()) // Checks whether the listener has the sender of the current Notification as target.
+                map->insert(std::pair<std::time_t, Notification*>(mapEntry.first, mapEntry.second));
         }
 
@@ -395,12 +395,12 @@
         The name of the NotificationQueue.
     @return
-        Returns a pointer to the NotificationQueue with the input name. Returns NULL if no NotificationQueue with such a name exists.
+        Returns a pointer to the NotificationQueue with the input name. Returns nullptr if no NotificationQueue with such a name exists.
     */
     NotificationQueue* NotificationManager::getQueue(const std::string & name)
     {
         std::map<const std::string, NotificationQueue*>::iterator it = this->queues_.find(name);
         // Returns NULL if no such NotificationQueue exists.
         if(it == this->queues_.end())
-            return NULL;
+            return nullptr;
 
         return (*it).second;
@@ -395,12 +395,12 @@
     {
         std::map<const std::string, NotificationQueue*>::iterator it = this->queues_.find(name);
-        // Returns NULL if no such NotificationQueue exists.
+        // Returns nullptr if no such NotificationQueue exists.
         if(it == this->queues_.end())